import Link from 'next/link'

const ExternalLink = ({ href, children }) => (
    <a
        className="text-gray-500 hover:text-gray-600 transition"
        target="_blank"
        rel="noopener noreferrer"
        href={href}
    >
        {children}
    </a>
)

export default function Footer() {
    return (
        <footer className="flex flex-col justify-center items-start w-full mt-8 mb-2">
            <hr className="w-full border-1 border-gray-200 dark:border-gray-800 mb-6" />
            <div className="w-full max-w-2xl grid grid-cols-1 gap-4 pb-16 sm:grid-cols-3">
                <div className="flex flex-col space-y-4">
                    <Link href="/">
                        <a className="text-gray-500 hover:text-gray-600 transition">
                            Home
                        </a>
                    </Link>
                    <Link href="/about">
                        <a className="text-gray-500 hover:text-gray-600 transition">
                            About
                        </a>
                    </Link>
                    <Link href="/newsletter">
                        <a className="text-gray-500 hover:text-gray-600 transition">
                            Newsletter
                        </a>
                    </Link>
                </div>
                <div className="flex flex-col space-y-4">
                    <ExternalLink href="https://twitter.com">
                        Twitter
                    </ExternalLink>
                    <ExternalLink href="https://github.com">
                        GitHub
                    </ExternalLink>
                    <ExternalLink href="https://www.youtube.com">
                        YouTube
                    </ExternalLink>
                </div>
                <div className="flex flex-col space-y-4">
                    <Link href="/uses">
                        <a className="text-gray-500 hover:text-gray-600 transition">
                            Uses
                        </a>
                    </Link>
                    <Link href="/snippets">
                        <a className="text-gray-500 hover:text-gray-600 transition">
                            Snippets
                        </a>
                    </Link>
                    <Link href="/tweets">
                        <a className="text-gray-500 hover:text-gray-600 transition">
                            Tweets
                        </a>
                    </Link>
                </div>
            </div>
        </footer>
    )
}
